@@ -21,32 +21,36 @@
 #include "wmapp.h"
 #include "ascii.h"
 #include "wmconfig.h"
+#include "wmaction.h"
 
 #include "intl.h"
 
 extern char *configArg;
 
 void setDefaultTheme(const char *theme) {
-    const char *buf = strJoin("Theme=\"", theme, "\"\n", NULL);
+    const char *buf = cstrJoin("Theme=\"", theme, "\"\n", NULL);
 
     setDefault("theme", buf);
 
     delete [] buf;
 }
 
-DTheme::DTheme(const char *label, const char *theme): DObject(label, 0) {
-    fTheme = newstr(theme);
+DTheme::DTheme(IApp *app, YSMListener *smActionListener, const ustring &label, const ustring &theme):
+    DObject(app, label, null), fTheme(theme)
+{
+    this->app = app;
+    this->smActionListener = smActionListener;
 }
 
 DTheme::~DTheme() {
-    delete[] fTheme;
 }
 
 void DTheme::open() {
-    if (!fTheme)
+    if (fTheme == null)
         return;
 
-    setDefaultTheme(fTheme);
+    cstring cTheme(fTheme);
+    setDefaultTheme(cTheme.c_str());
 
     const char *bg[] = { ICEWMBGEXE, "-r", 0 };
     int pid = app->runProgram(bg[0], bg);
@@ -54,10 +58,13 @@ void DTheme::open() {
 
     YStringArray args(4);
 
-    wmapp->restartClient(0, 0);
+    smActionListener->handleSMAction(ICEWM_ACTION_RESTARTWM);
 }
 
-ThemesMenu::ThemesMenu(YWindow *parent): ObjectMenu(parent) {
+ThemesMenu::ThemesMenu(IApp *app, YSMListener *smActionListener, YActionListener *wmActionListener, YWindow *parent): ObjectMenu(wmActionListener, parent) {
+    this->app = app;
+    this->smActionListener = smActionListener;
+    this->wmActionListener = wmActionListener;
 }
 
 void ThemesMenu::updatePopup() {
@@ -71,25 +78,25 @@ void ThemesMenu::refresh() {
 
     if (nestedThemeMenuMinNumber)
         themeCount =
-            countThemes(strJoin(libDir, "/themes/", NULL)) +
-            countThemes(strJoin(configDir, "/themes/", NULL)) +
-            countThemes(strJoin(YApplication::getPrivConfDir(),
+            countThemes(cstrJoin(YApplication::getLibDir(), "/themes/", NULL)) +
+            countThemes(cstrJoin(YApplication::getConfigDir(), "/themes/", NULL)) +
+            countThemes(cstrJoin(YApplication::getPrivConfDir(),
                                 "/themes/", NULL));
 
-    path = strJoin(libDir, "/themes/", NULL);
+    path = cstrJoin(YApplication::getLibDir(), "/themes/", NULL);
     findThemes(path, this);
     delete[] path;
 
-    path = strJoin(configDir, "/themes/", NULL);
+    path = cstrJoin(YApplication::getConfigDir(), "/themes/", NULL);
     findThemes(path, this);
     delete[] path;
 
-    path = strJoin(YApplication::getPrivConfDir(), "/themes/", NULL);
+    path = cstrJoin(YApplication::getPrivConfDir(), "/themes/", NULL);
     findThemes(path, this);
     delete[] path;
 
     addSeparator();
-    add(newThemeItem(_("Default"), CONFIG_DEFAULT_THEME, CONFIG_DEFAULT_THEME));
+    add(newThemeItem(app, smActionListener, _("Default"), CONFIG_DEFAULT_THEME, CONFIG_DEFAULT_THEME));
 }
 
 int ThemesMenu::countThemes(const char *path) {
@@ -102,6 +109,9 @@ int ThemesMenu::countThemes(const char *path) {
            // assume that OS caches this. Otherwise, construct a new
            // object to just store the string and an YArrayList of them,
            // read the entries once and work with List contents later
+
+           if(de->d_name[0] == '.')
+              continue;
            ret++;
         }
         closedir(dir);
@@ -113,8 +123,8 @@ int ThemesMenu::countThemes(const char *path) {
 ThemesMenu::~ThemesMenu() {
 }
 
-YMenuItem * ThemesMenu::newThemeItem(char const *label, char const */*theme*/, char const *relThemeName) {
-    DTheme *dtheme = new DTheme(label, relThemeName);
+YMenuItem * ThemesMenu::newThemeItem(IApp *app, YSMListener *smActionListener, char const *label, char const */*theme*/, char const *relThemeName) {
+    DTheme *dtheme = new DTheme(app, smActionListener, label, relThemeName);
 
     if (dtheme) {
         YMenuItem *item(new DObjectMenuItem(dtheme));
@@ -129,61 +139,58 @@ YMenuItem * ThemesMenu::newThemeItem(char const *label, char const */*theme*/, c
 
 void ThemesMenu::findThemes(const char *path, YMenu *container) {
     char const *const tname("/default.theme");
-    bool isFirst(true);
 
     int dplen(strlen(path));
     char *npath = NULL, *dpath = NULL;
 
     if (dplen == 0 || path[dplen - 1] != '/') {
-        npath = strJoin(path, "/", NULL);
+        npath = cstrJoin(path, "/", NULL);
         dplen++;
     } else {
         dpath = newstr(path);
     }
 
+    bool bNesting = nestedThemeMenuMinNumber && themeCount>nestedThemeMenuMinNumber;
+
     DIR *dir(opendir(path));
 
     if (dir != NULL) {
         struct dirent *de;
         while ((de = readdir(dir)) != NULL) {
+
+           if (de->d_name[0] == '.')
+              continue;
+
             YMenuItem *im(NULL);
-            npath = strJoin(dpath, de->d_name, tname, NULL);
+            npath = cstrJoin(dpath, de->d_name, tname, NULL);
 
             if (npath && access(npath, R_OK) == 0) {
-                if (isFirst) {
-                    isFirst = false;
-//              if (itemCount())
-//                        addSeparator();
-                    //addLabel(path);
-                    //addSeparator();
-                }
-                char *relThemeName = strJoin(de->d_name, tname, NULL);
-                im = newThemeItem(de->d_name, npath, relThemeName);
+                char *relThemeName = cstrJoin(de->d_name, tname, NULL);
+                im = newThemeItem(app, smActionListener, de->d_name, npath, relThemeName);
                 if (im) {
-                    if (nestedThemeMenuMinNumber && themeCount>nestedThemeMenuMinNumber) {
-                        int targetItem = container->findFirstLetRef(de->d_name[0], 0, 1);
-                        char *smname = strdup("....");
-                        *smname = ASCII::toUpper(de->d_name[0]);
-                        if (targetItem >= 0) {
-                            YMenuItem *oldSibling = container->getItem(targetItem);
-                            // we have something with this letter
-                            if (0 == strcmp(smname, oldSibling->getName())) {
-                                // is our submenu
-                                (oldSibling->getSubmenu())->addSorted(im, true);
-                            } else {
-                                // menu a new item, a menu under it, move
-                                // the theme item to the submenu and assign
-                                // oldSibling reference to it
-                                YMenu *smenu = new YMenu();
-                                YMenuItem *smItem = new YMenuItem(smname, 0, NULL, NULL, smenu);
-                                if(smItem && smenu) {
-                                   smenu->addSorted(oldSibling, false);
-                                   smenu->addSorted(im, false);
-                                   container->setItem(targetItem, smItem);
-                                }
+                    if (bNesting) 
+                    {
+                       char fLetter = ASCII::toUpper(de->d_name[0]);
+
+                        int targetItem = container->findFirstLetRef(fLetter, 0, 1);
+                        
+                        if (targetItem < 0) // no submenu for us yet, create one
+                        {
+                            char *smname = strdup("....");
+                            smname[0] = fLetter;
+
+                            YMenu *smenu = new YMenu();
+                            YMenuItem *smItem = new YMenuItem(smname, 0, null, NULL, smenu);
+                            if(smItem && smenu)
+                                container->addSorted(smItem, false);
+                            targetItem = container->findFirstLetRef(fLetter, 0, 1);
+                            if (targetItem < 0)
+                            {
+                                warn("Failed to add submenu");
+                                return;
                             }
-                        } else //no sibling, add a plain icon
-                            container->addSorted(im, false);
+                        }
+                        container->getItem(targetItem)->getSubmenu()->addSorted(im, false);
                     } else //the default method without Extra SubMenues
                         container->addSorted(im, false);
                 }
@@ -192,8 +199,10 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
 
             delete [] npath;
 
-            char *subdir(strJoin(dpath, de->d_name, NULL));
-            if (im && subdir) findThemeAlternatives(subdir, de->d_name, im);
+            char *subdir(cstrJoin(dpath, de->d_name, NULL));
+            if (im && subdir) {
+                findThemeAlternatives(app, smActionListener, subdir, de->d_name, im);
+            }
             delete [] subdir;
         }
 
@@ -203,8 +212,13 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
     delete [] dpath;
 }
 
-void ThemesMenu::findThemeAlternatives(const char *path, const char *relName,
-                                       YMenuItem *item)
+
+void ThemesMenu::findThemeAlternatives(
+    IApp *app,
+    YSMListener *smActionListener,
+    const char *path,
+    const char *relName,
+    YMenuItem *item)
 {
     DIR *dir(opendir(path));
 
@@ -216,7 +230,7 @@ void ThemesMenu::findThemeAlternatives(const char *path, const char *relName,
             if (ext != NULL && ext[sizeof("theme")] == '\0' &&
                 strcmp(de->d_name, "default.theme"))
             {
-                char *npath(strJoin(path, "/", de->d_name, NULL));
+                char *npath(cstrJoin(path, "/", de->d_name, NULL));
 
                 if (npath && access(npath, R_OK) == 0) {
                     YMenu *sub(item->getSubmenu());
@@ -226,9 +240,9 @@ void ThemesMenu::findThemeAlternatives(const char *path, const char *relName,
 
                     if (sub) {
                         char *tname(newstr(de->d_name, ext - de->d_name));
-                        char *relThemeName = strJoin(relName, "/",
+                        char *relThemeName = cstrJoin(relName, "/",
                                                      de->d_name, NULL);
-                        sub->add(newThemeItem(tname, npath, relThemeName));
+                        sub->add(newThemeItem(app, smActionListener, tname, npath, relThemeName));
                         delete[] tname;
                         delete[] relThemeName;
                     }
