@@ -53,7 +53,8 @@ void DObjectMenuItem::actionPerformed(YActionListener * /*listener*/, YAction *
     fObject->open();
 }
 
-DFile::DFile(const ustring &name, ref<YIcon> icon, upath path): DObject(name, icon) {
+DFile::DFile(IApp *app, const ustring &name, ref<YIcon> icon, upath path): DObject(app, name, icon) {
+    this->app = app;
     fPath = path;
 }
 
@@ -65,8 +66,8 @@ void DFile::open() {
     app->runProgram(openCommand, args);
 }
 
-ObjectMenu::ObjectMenu(YWindow *parent): YMenu(parent) {
-    setActionListener(wmapp);
+ObjectMenu::ObjectMenu(YActionListener *actionListener, YWindow *parent): YMenu(parent) {
+    setActionListener(actionListener);
 }
 
 ObjectMenu::~ObjectMenu() {
@@ -98,9 +99,10 @@ void ObjectMenu::addContainer(const ustring &name, ref<YIcon> icon, ObjectContai
     }
 }
 
-DObject::DObject(const ustring &name, ref<YIcon> icon):
+DObject::DObject(IApp *app, const ustring &name, ref<YIcon> icon):
     fName(name), fIcon(icon)
 {
+    this->app = app;
 }
 
 DObject::~DObject() {
@@ -110,11 +112,23 @@ DObject::~DObject() {
 void DObject::open() {
 }
 
-DProgram::DProgram(const ustring &name, ref<YIcon> icon, const bool restart,
-                   const char *wmclass, upath exe, YStringArray &args):
-    DObject(name, icon), fRestart(restart),
-    fRes(newstr(wmclass)), fCmd(exe), fArgs(args)
+DProgram::DProgram(
+    IApp *app,
+    YSMListener *smActionListener,
+    const ustring &name,
+    ref<YIcon> icon,
+    const bool restart,
+    const char *wmclass,
+    upath exe,
+    YStringArray &args)
+    : DObject(app, name, icon),
+    fRestart(restart),
+    fRes(newstr(wmclass)),
+    fCmd(exe),
+    fArgs(args)
 {
+    this->app = app;
+    this->smActionListener = smActionListener;
     if (fArgs.isEmpty() || fArgs.getString(fArgs.getCount() - 1))
         fArgs.append(0);
 }
@@ -125,17 +139,23 @@ DProgram::~DProgram() {
 
 void DProgram::open() {
     if (fRestart)
-        wmapp->restartClient(cstring(fCmd.path()).c_str(), fArgs.getCArray());
+        smActionListener->restartClient(cstring(fCmd.path()).c_str(), fArgs.getCArray());
     else if (fRes)
-        wmapp->runOnce(fRes, cstring(fCmd.path()).c_str(), fArgs.getCArray());
+        smActionListener->runOnce(fRes, cstring(fCmd.path()).c_str(), fArgs.getCArray());
     else
         app->runProgram(cstring(fCmd.path()).c_str(), fArgs.getCArray());
 }
 
-DProgram *DProgram::newProgram(const char *name, ref<YIcon> icon,
-                               const bool restart, const char *wmclass,
-                               upath exe, YStringArray &args) {
-
+DProgram *DProgram::newProgram(
+    IApp *app,
+    YSMListener *smActionListener,
+    const char *name,
+    ref<YIcon> icon,
+    const bool restart,
+    const char *wmclass,
+    upath exe,
+    YStringArray &args)
+{
     if (exe != null) {
         MSG(("LOOKING FOR: %s\n", cstring(exe.path()).c_str()));
         upath fullname = findPath(getenv("PATH"), X_OK, exe);
@@ -145,7 +165,7 @@ DProgram *DProgram::newProgram(const char *name, ref<YIcon> icon,
         }
 
         DProgram *program =
-            new DProgram(name, icon, restart, wmclass, fullname, args);
+            new DProgram(app, smActionListener, name, icon, restart, wmclass, fullname, args);
 
         return program;
     }
@@ -208,7 +228,7 @@ KProgram::KProgram(const char *key, DProgram *prog) {
     keyProgs = this;
 }
 
-char *parseIncludeStatement(char *p, ObjectContainer *container) {
+char *parseIncludeStatement(IApp *app, YSMListener *smActionListener, YActionListener *wmActionListener, char *p, ObjectContainer *container) {
     char *filename;
 
     p = YConfig::getArgument(&filename, p, false);
@@ -221,15 +241,15 @@ char *parseIncludeStatement(char *p, ObjectContainer *container) {
     delete[] filename;
 
     if (!path.isAbsolute())
-        path = YApplication::findConfigFile(path);
+        path = app->findConfigFile(path);
 
     if (path != null)
-        loadMenus(path, container);
+        loadMenus(app, smActionListener, wmActionListener, path, container);
 
     return p;
 }
 
-char *parseMenus(char *data, ObjectContainer *container) {
+char *parseMenus(IApp *app, YSMListener *smActionListener, YActionListener *wmActionListener, char *data, ObjectContainer *container) {
     char *p = data;
     char word[32];
 
@@ -279,10 +299,15 @@ char *parseMenus(char *data, ObjectContainer *container) {
 #ifndef LITE
                 if (icons[0] != '-') icon = YIcon::getIcon(icons);
 #endif
-                DProgram * prog =
-                    DProgram::newProgram(name, icon,
-                                         word[1] == 'e', word[1] == 'u' ? wmclass : 0,
-                                         command, args);
+                DProgram * prog = DProgram::newProgram(
+                    app,
+                    smActionListener,
+                    name,
+                    icon,
+                    word[1] == 'e',
+                    word[1] == 'u' ? wmclass : 0,
+                    command,
+                    args);
 
                 if (prog) container->addObject(prog);
 
@@ -311,10 +336,10 @@ char *parseMenus(char *data, ObjectContainer *container) {
                     icon = YIcon::getIcon(icons);
 #endif
 
-                ObjectMenu *sub = new ObjectMenu();
+                ObjectMenu *sub = new ObjectMenu(wmActionListener);
 
                 if (sub) {
-                    p = parseMenus(p, sub);
+                    p = parseMenus(app, smActionListener, wmActionListener, p, sub);
 
                     if (sub->itemCount() == 0)
                         delete sub;
@@ -348,7 +373,7 @@ char *parseMenus(char *data, ObjectContainer *container) {
                 if (icons[0] != '-')
                     icon = YIcon::getIcon(icons);
 #endif
-                ObjectMenu *filemenu = new MenuFileMenu(menufile, 0);
+                ObjectMenu *filemenu = new MenuFileMenu(app, smActionListener, wmActionListener, menufile, 0);
 
                 if (menufile)
                     container->addContainer(name, icon, filemenu);
@@ -383,7 +408,7 @@ char *parseMenus(char *data, ObjectContainer *container) {
 
                 upath fullPath = findPath(getenv("PATH"), X_OK, command);
                 if (fullPath != null) {
-                    ObjectMenu *progmenu = new MenuProgMenu(name, command, args, 0);
+                    ObjectMenu *progmenu = new MenuProgMenu(app, smActionListener, wmActionListener, name, command, args, 0);
                     if (progmenu)
                         container->addContainer(name, icon, progmenu);
                 }
@@ -425,7 +450,7 @@ char *parseMenus(char *data, ObjectContainer *container) {
 
                 upath fullPath = findPath(getenv("PATH"), X_OK, command);
                 if (fullPath != null) {
-                    ObjectMenu *progmenu = new MenuProgReloadMenu(name, timeout, command, args, 0);
+                    ObjectMenu *progmenu = new MenuProgReloadMenu(app, smActionListener, wmActionListener, name, timeout, command, args, 0);
                     if (progmenu)
                         container->addContainer(name, icon, progmenu);
                 }
@@ -434,7 +459,7 @@ char *parseMenus(char *data, ObjectContainer *container) {
                 delete[] timeoutStr;
                 delete[] command;
             } else if (!strcmp(word, "include"))
-                p = parseIncludeStatement(p, container);
+                p = parseIncludeStatement(app, smActionListener, wmActionListener, p, container);
             else if (*p == '}')
                 return ++p;
             else {
@@ -465,10 +490,15 @@ char *parseMenus(char *data, ObjectContainer *container) {
                     return p;
                 }
 
-                DProgram *prog =
-                    DProgram::newProgram(key, null, false,
-                                         *word == 'r' ? wmclass : 0,
-                                         command, args);
+                DProgram *prog = DProgram::newProgram(                
+                    app,
+                    smActionListener,
+                    key,
+                    null,
+                    false,
+                    *word == 'r' ? wmclass : 0,
+                    command,
+                    args);
 
                 if (prog) new KProgram(key, prog);
                 delete[] key;
@@ -482,7 +512,7 @@ char *parseMenus(char *data, ObjectContainer *container) {
     return p;
 }
 
-static void loadMenus(int fd, ObjectContainer *container) {
+static void loadMenus(IApp *app, YSMListener *smActionListener, YActionListener *wmActionListener, int fd, ObjectContainer *container) {
     if (fd == -1) return;
 
     struct stat sb;
@@ -518,18 +548,33 @@ static void loadMenus(int fd, ObjectContainer *container) {
     }
     close(fd);
 
-    parseMenus(buf, container);
+    parseMenus(app, smActionListener, wmActionListener, buf, container);
 
     delete[] buf;
 }
 
-void loadMenus(upath menufile, ObjectContainer *container) {
+void loadMenus(
+    IApp *app, 
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    upath menufile,
+    ObjectContainer *container)
+{
     MSG(("menufile: %s", cstring(menufile.path()).c_str()));
     cstring cs(menufile.path());
-    loadMenus(open(cs.c_str(), O_RDONLY | O_TEXT), container);
+    loadMenus(app, smActionListener, wmActionListener, open(cs.c_str(), O_RDONLY | O_TEXT), container);
 }
 
-MenuFileMenu::MenuFileMenu(ustring name, YWindow *parent): ObjectMenu(parent), fName(name) {
+MenuFileMenu::MenuFileMenu(
+    IApp *app,
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    ustring name,
+    YWindow *parent)
+    : ObjectMenu(wmActionListener, parent), fName(name)
+{
+    this->app = app;
+    this->smActionListener = smActionListener;
     fName = name;
     fPath = 0;
     fModTime = 0;
@@ -544,7 +589,7 @@ void MenuFileMenu::updatePopup() {
     if (!autoReloadMenus && fPath != null)
         return;
 
-    upath np = YApplication::findConfigFile(upath(fName));
+    upath np = app->findConfigFile(upath(fName));
     bool rel = false;
 
 
@@ -577,10 +622,17 @@ void MenuFileMenu::updatePopup() {
 void MenuFileMenu::refresh() {
     removeAll();
     if (fPath != null)
-        loadMenus(fPath, this);
+        loadMenus(app, smActionListener, wmActionListener, fPath, this);
 }
 
-void loadMenusProg(const char *command, char *const argv[], ObjectContainer *container) {
+void loadMenusProg(
+    IApp *app,
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    const char *command,
+    char *const argv[],
+    ObjectContainer *container)
+{
     int fds[2];
     pid_t child_pid;
     int status;
@@ -603,7 +655,7 @@ void loadMenusProg(const char *command, char *const argv[], ObjectContainer *con
         default:
             close(fds[1]);
 
-            loadMenus(fds[0], container);
+            loadMenus(app, smActionListener, wmActionListener, fds[0], container);
             waitpid(child_pid, &status, 0);
             close(fds[0]);
             break;
@@ -615,7 +667,18 @@ void loadMenusProg(const char *command, char *const argv[], ObjectContainer *con
     }
 }
 
-MenuProgMenu::MenuProgMenu(ustring name, upath command, YStringArray &args, YWindow *parent): ObjectMenu(parent), fName(name), fCommand(command), fArgs(args) {
+MenuProgMenu::MenuProgMenu(
+    IApp *app,
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    ustring name,
+    upath command,
+    YStringArray &args,
+    YWindow *parent)
+    : ObjectMenu(wmActionListener, parent), fName(name), fCommand(command), fArgs(args)
+{
+    this->app = app;
+    this->smActionListener = smActionListener;
     fName = name;
     fCommand = command;
     fArgs.append(0);
@@ -665,29 +728,51 @@ void MenuProgMenu::updatePopup() {
     }
 #endif
     if (fModTime == 0)
-        refresh();
+        refresh(smActionListener, wmActionListener);
     fModTime = time(NULL);
 /// TODO #warning "figure out some way for this to work"
 }
 
-void MenuProgMenu::refresh() {
+void MenuProgMenu::refresh(
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener)
+{
     removeAll();
     if (fCommand != null)
-        loadMenusProg(cstring(fCommand.path()).c_str(), fArgs.getCArray(), this);
+        loadMenusProg(app, smActionListener, wmActionListener, cstring(fCommand.path()).c_str(), fArgs.getCArray(), this);
 }
 
-MenuProgReloadMenu::MenuProgReloadMenu(const char *name, time_t timeout, const char *command, YStringArray &args, YWindow *parent) : MenuProgMenu(name, command, args, parent) {
+MenuProgReloadMenu::MenuProgReloadMenu(
+    IApp *app,
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    const char *name,
+    time_t timeout,
+    const char *command,
+    YStringArray &args,
+    YWindow *parent)
+    : MenuProgMenu(app, smActionListener, wmActionListener, name, command, args, parent)
+{
     fTimeout = timeout;
 }
 
 void MenuProgReloadMenu::updatePopup() {
     if (fModTime == 0 || time(NULL) >= fModTime + fTimeout) {
-        refresh();
+        refresh(smActionListener, wmActionListener);
         fModTime = time(NULL);
     }
 }
 
-StartMenu::StartMenu(const char *name, YWindow *parent): MenuFileMenu(name, parent) {
+StartMenu::StartMenu(
+    IApp *app,
+    YSMListener *smActionListener,
+    YActionListener *wmActionListener,
+    const char *name,
+    YWindow *parent)
+    : MenuFileMenu(app, smActionListener, wmActionListener, name, parent)
+{
+    this->smActionListener = smActionListener;
+    this->wmActionListener = wmActionListener;
     fHasGnomeAppsMenu =
         fHasGnomeUserMenu =
         fHasKDEMenu = false;
@@ -699,7 +784,7 @@ StartMenu::StartMenu(const char *name, YWindow *parent): MenuFileMenu(name, pare
 bool StartMenu::handleKey(const XKeyEvent &key) {
     // If meta key, close the popup
     if (key.type == KeyPress) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 0);
+        KeySym k = keyCodeToKeySym(key.keycode);
         int m = KEY_MODMASK(key.state);
 
         if (((k == xapp->Win_L) || (k == xapp->Win_R)) && m == 0) {
@@ -733,8 +818,8 @@ void StartMenu::refresh() {
         for (unsigned int i = 0; i < sizeof(path)/sizeof(path[0]); i++) {
             const char *p = path[i];
 
-            sub = new BrowseMenu(p);
-            DFile *file = new DFile(p, null, p);
+            sub = new BrowseMenu(app, smActionListener, wmActionListener, p);
+            DFile *file = new DFile(app, p, null, p);
             YMenuItem *item = add(new DObjectMenuItem(file));
             if (item && sub) {
                 item->setSubmenu(sub);
@@ -752,7 +837,7 @@ void StartMenu::refresh() {
 #endif
 
     if (showPrograms) {
-        ObjectMenu *programs = new MenuFileMenu("programs", 0);
+        ObjectMenu *programs = new MenuFileMenu(app, smActionListener, wmActionListener, "programs", 0);
         ///    if (programs->itemCount() > 0)
         addSubmenu(_("Programs"), 0, programs);
     }
@@ -800,9 +885,15 @@ void StartMenu::refresh() {
         args.append(ICEHELPIDX);
         args.append(0);
 
-        DProgram *help =
-            DProgram::newProgram(_("_Help"), null, false, "browser.IceHelp",
-                                 ICEHELPEXE, args);
+        DProgram *help = DProgram::newProgram(
+            app,
+            smActionListener,
+            _("_Help"),
+            null,
+            false,
+            "browser.IceHelp",
+            ICEHELPEXE,
+            args);
 
         if (help) addObject(help);
     }
@@ -836,7 +927,7 @@ void StartMenu::refresh() {
 
 
         if (showThemesMenu) {
-            YMenu *themes = new ThemesMenu();
+            YMenu *themes = new ThemesMenu(app, smActionListener, wmActionListener);
             if (themes)
                 settings->addSubmenu(_("_Themes"), -2, themes);
         }
