@@ -23,6 +23,8 @@ class TaskPane;
 class TrayPane;
 class WorkspacesPane;
 class YXTray;
+class YSMListener;
+class IApp;
 
 class IAppletContainer {
 public:
@@ -62,7 +64,7 @@ class TaskBar:
     public IAppletContainer
 {
 public:
-    TaskBar(YWindow *aParent);
+    TaskBar(IApp *app, YWindow *aParent, YActionListener *wmActionListener, YSMListener *smActionListener);
     virtual ~TaskBar();
 
     virtual void paint(Graphics &g, const YRect &r);
@@ -167,6 +169,9 @@ private:
     AddressBar *fAddressBar;
     WorkspacesPane *fWorkspaces;
     YXTray *fDesktopTray;
+    YActionListener *wmActionListener;
+    YSMListener *smActionListener;
+    IApp *app;
 
     bool fIsHidden;
     bool fFullscreen;
